// src/exporters/utils.ts
import { hrTimeToNanoseconds, hexToBase64 } from "@opentelemetry/core";
import { toAttributes, toAnyValue } from "@opentelemetry/otlp-transformer/build/src/common/internal";
function createExportLogsServiceRequest(spans, useHex) {
  return {
    resourceLogs: spanRecordsToResourceLogs(spans, useHex)
  };
}
function createResourceMap(logRecords) {
  const resourceMap = /* @__PURE__ */ new Map();
  for (const record of logRecords) {
    let ilmMap = resourceMap.get(record.resource);
    if (!ilmMap) {
      ilmMap = /* @__PURE__ */ new Map();
      resourceMap.set(record.resource, ilmMap);
    }
    const instrumentationLibraryKey = `opentelemetry-sdk-workers@:`;
    let records = ilmMap.get(instrumentationLibraryKey);
    if (!records) {
      records = [];
      ilmMap.set(instrumentationLibraryKey, records);
    }
    records.push(record);
  }
  return resourceMap;
}
function spanRecordsToResourceLogs(logRecords, useHex) {
  const resourceMap = createResourceMap(logRecords);
  const out = [];
  for (const [resource, ilmMap] of resourceMap) {
    const scopeResourceLogs = [];
    for (const [, scopeLogs] of ilmMap) {
      if (scopeLogs.length > 0) {
        const { name, version } = scopeLogs[0].instrumentationLibrary;
        const logs = scopeLogs.map(
          (logRecord) => sdkLogRecordToOtlpSpan(logRecord, useHex)
        );
        scopeResourceLogs.push({
          scope: { name, version },
          logRecords: logs
        });
      }
    }
    const transformedSpans = {
      resource: {
        attributes: toAttributes(resource.attributes),
        droppedAttributesCount: 0
      },
      scopeLogs: scopeResourceLogs
    };
    out.push(transformedSpans);
  }
  const entryIterator = resourceMap.entries();
  let entry = entryIterator.next();
  while (!entry.done) {
    const [resource, ilmMap] = entry.value;
    entry = entryIterator.next();
  }
  return out;
}
function sdkLogRecordToOtlpSpan(logRecord, useHex) {
  return {
    timeUnixNano: hrTimeToNanoseconds(logRecord.timestamp),
    observedTimeUnixNano: hrTimeToNanoseconds(logRecord.observedTimestamp),
    severityNumber: logRecord.severityNumber,
    severityText: logRecord.severityText,
    body: toAnyValue(logRecord.body),
    attributes: toAttributes(logRecord.attributes),
    droppedAttributesCount: 0,
    traceId: useHex ? logRecord.traceId : hexToBase64(logRecord.traceId),
    spanId: useHex ? logRecord.spanId : hexToBase64(logRecord.spanId)
  };
}

export {
  createExportLogsServiceRequest
};
