var __accessCheck = (obj, member, msg) => {
  if (!member.has(obj))
    throw TypeError("Cannot " + msg);
};
var __privateGet = (obj, member, getter) => {
  __accessCheck(obj, member, "read from private field");
  return getter ? getter.call(obj) : member.get(obj);
};
var __privateAdd = (obj, member, value) => {
  if (member.has(obj))
    throw TypeError("Cannot add the same private member more than once");
  member instanceof WeakSet ? member.add(obj) : member.set(obj, value);
};
var __privateSet = (obj, member, value, setter) => {
  __accessCheck(obj, member, "write to private field");
  setter ? setter.call(obj, value) : member.set(obj, value);
  return value;
};
var __privateMethod = (obj, member, method) => {
  __accessCheck(obj, member, "access private method");
  return method;
};

// src/exporters/OTLPCloudflareExporterBase.ts
import { diag } from "@opentelemetry/api";
import { baggageUtils, ExportResultCode } from "@opentelemetry/core";
import {
  configureExporterTimeout,
  OTLPExporterError,
  parseHeaders
} from "@opentelemetry/otlp-exporter-base";

// node_modules/lodash-es/_freeGlobal.js
var freeGlobal = typeof global == "object" && global && global.Object === Object && global;
var freeGlobal_default = freeGlobal;

// node_modules/lodash-es/_root.js
var freeSelf = typeof self == "object" && self && self.Object === Object && self;
var root = freeGlobal_default || freeSelf || void 0;
var root_default = root;

// node_modules/lodash-es/_Symbol.js
var Symbol2 = root_default.Symbol;
var Symbol_default = Symbol2;

// node_modules/lodash-es/_getRawTag.js
var objectProto = Object.prototype;
var hasOwnProperty = objectProto.hasOwnProperty;
var nativeObjectToString = objectProto.toString;
var symToStringTag = Symbol_default ? Symbol_default.toStringTag : void 0;
function getRawTag(value) {
  var isOwn = hasOwnProperty.call(value, symToStringTag), tag = value[symToStringTag];
  try {
    value[symToStringTag] = void 0;
    var unmasked = true;
  } catch (e) {
  }
  var result = nativeObjectToString.call(value);
  if (unmasked) {
    if (isOwn) {
      value[symToStringTag] = tag;
    } else {
      delete value[symToStringTag];
    }
  }
  return result;
}
var getRawTag_default = getRawTag;

// node_modules/lodash-es/_objectToString.js
var objectProto2 = Object.prototype;
var nativeObjectToString2 = objectProto2.toString;
function objectToString(value) {
  return nativeObjectToString2.call(value);
}
var objectToString_default = objectToString;

// node_modules/lodash-es/_baseGetTag.js
var nullTag = "[object Null]";
var undefinedTag = "[object Undefined]";
var symToStringTag2 = Symbol_default ? Symbol_default.toStringTag : void 0;
function baseGetTag(value) {
  if (value == null) {
    return value === void 0 ? undefinedTag : nullTag;
  }
  return symToStringTag2 && symToStringTag2 in Object(value) ? getRawTag_default(value) : objectToString_default(value);
}
var baseGetTag_default = baseGetTag;

// node_modules/lodash-es/isObjectLike.js
function isObjectLike(value) {
  return value != null && typeof value == "object";
}
var isObjectLike_default = isObjectLike;

// node_modules/lodash-es/_overArg.js
function overArg(func, transform) {
  return function(arg) {
    return func(transform(arg));
  };
}
var overArg_default = overArg;

// node_modules/lodash-es/_getPrototype.js
var getPrototype = overArg_default(Object.getPrototypeOf, Object);
var getPrototype_default = getPrototype;

// node_modules/lodash-es/isPlainObject.js
var objectTag = "[object Object]";
var funcProto = Function.prototype;
var objectProto3 = Object.prototype;
var funcToString = funcProto.toString;
var hasOwnProperty2 = objectProto3.hasOwnProperty;
var objectCtorString = funcToString.call(Object);
function isPlainObject(value) {
  if (!isObjectLike_default(value) || baseGetTag_default(value) != objectTag) {
    return false;
  }
  var proto = getPrototype_default(value);
  if (proto === null) {
    return true;
  }
  var Ctor = hasOwnProperty2.call(proto, "constructor") && proto.constructor;
  return typeof Ctor == "function" && Ctor instanceof Ctor && funcToString.call(Ctor) == objectCtorString;
}
var isPlainObject_default = isPlainObject;

// node_modules/lodash-es/isError.js
var domExcTag = "[object DOMException]";
var errorTag = "[object Error]";
function isError(value) {
  if (!isObjectLike_default(value)) {
    return false;
  }
  var tag = baseGetTag_default(value);
  return tag == errorTag || tag == domExcTag || typeof value.message == "string" && typeof value.name == "string" && !isPlainObject_default(value);
}
var isError_default = isError;

// src/exporters/OTLPCloudflareExporterBase.ts
var OTLPCloudflareExporterBase = class {
  /**
   * @param config
   */
  constructor(config = {}) {
    this.DEFAULT_HEADERS = {};
    this._sendingPromises = [];
    this.url = this.getUrl(config);
    if (config.metadata) {
      diag.warn("Metadata cannot be set when using http");
    }
    this.headers = Object.assign(
      this.DEFAULT_HEADERS,
      parseHeaders(config.headers)
    );
    this._concurrencyLimit = typeof config.concurrencyLimit === "number" ? config.concurrencyLimit : Infinity;
    this.timeoutMillis = configureExporterTimeout(config.timeoutMillis);
    this.enableCompression = config.compress ?? true;
  }
  static parseEnv(env, exporterType) {
    const headers = baggageUtils.parseKeyPairsIntoRecord(env[`OTEL_EXPORTER_OTLP_${exporterType}_HEADERS`] ?? env["OTEL_EXPORTER_OTLP_HEADERS"] ?? "");
    const compressRawValue = env[`OTEL_EXPORTER_${exporterType}_COMPRESSION_ENABLED`] ?? env["OTEL_EXPORTER_COMPRESSION_ENABLED"] ?? "true";
    const compress = !(compressRawValue === "0" || compressRawValue === "false");
    return {
      endpoints: {
        default: env["OTEL_EXPORTER_OTLP_ENDPOINT"] ?? env["OTLP_ENDPOINT"],
        traces: env["OTEL_EXPORTER_OTLP_TRACES_ENDPOINT"],
        logs: env["OTEL_EXPORTER_OTLP_LOGS_ENDPOINT"]
      },
      headers,
      compress
    };
  }
  /**
   * Export items.
   * @param items
   * @param resultCallback
   */
  export(items, resultCallback) {
    if (this._sendingPromises.length >= this._concurrencyLimit) {
      resultCallback({
        code: ExportResultCode.FAILED,
        error: new Error("Concurrent export limit reached")
      });
      return;
    }
    this._export(items).then(() => {
      resultCallback({ code: ExportResultCode.SUCCESS });
    }).catch((error) => {
      resultCallback({ code: ExportResultCode.FAILED, error });
    });
  }
  _export(items) {
    diag.debug("items to be sent", items);
    return this.send(items);
  }
  compress(response) {
    return { body: response.body, headers: {} };
  }
  send(items) {
    const serviceRequest = this.convert(items);
    let body = serviceRequest instanceof Uint8Array ? serviceRequest : JSON.stringify(serviceRequest);
    const signal = AbortSignal.timeout(
      this.timeoutMillis
    );
    const responseBuffer = new Response(body);
    const compressed = this.compress(responseBuffer);
    const promise = fetch(this.url, {
      method: "POST",
      headers: {
        "content-type": this.contentType,
        ...compressed.headers,
        ...this.headers
      },
      body: compressed.body,
      signal,
      // @ts-ignore
      duplex: "half"
    }).then((res) => {
      if (!res.ok) {
        throw new OTLPExporterError(res.statusText, res.status);
      }
    }).catch((error) => {
      if (isError_default(error)) {
        if (error.name === "TimeoutError") {
          throw new OTLPExporterError("Request Timeout");
        }
      }
      throw new OTLPExporterError(`There was an error sending spans:
	${error}
Double check that your exporter URL is correct and the endpoint is valid.`);
    });
    this._sendingPromises.push(promise);
    return promise;
  }
  /**
   * Shutdown the exporter.
   */
  shutdown() {
    throw new Error("Shutdown is not supported by this exporter.");
  }
};

export {
  __privateGet,
  __privateAdd,
  __privateSet,
  __privateMethod,
  OTLPCloudflareExporterBase
};
/*! Bundled license information:

lodash-es/lodash.js:
  (**
   * @license
   * Lodash (Custom Build) <https://lodash.com/>
   * Build: `lodash modularize exports="es" -o ./`
   * Copyright OpenJS Foundation and other contributors <https://openjsf.org/>
   * Released under MIT license <https://lodash.com/license>
   * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
   * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
   *)
*/
