import {
  createExportLogsServiceRequest
} from "../chunk-UBB7SZAJ.js";
import {
  opentelemetry
} from "../chunk-JQEWNB4B.js";
import {
  OTLPCloudflareExporterBase
} from "../chunk-WEQB7WXV.js";

// src/exporters/OTLPProtoLogExporter.ts
import { appendResourcePathToUrl, appendRootPathToUrlIfNeeded } from "@opentelemetry/otlp-exporter-base";
var DEFAULT_COLLECTOR_RESOURCE_PATH = "v1/logs";
var {
  proto: {
    collector: {
      logs: {
        v1: { ExportLogsServiceRequest }
      }
    }
  }
} = opentelemetry;
var OTLPProtoLogExporter = class _OTLPProtoLogExporter extends OTLPCloudflareExporterBase {
  constructor() {
    super(...arguments);
    this.contentType = "application/x-protobuf";
  }
  static fromEnv(env) {
    return new _OTLPProtoLogExporter(OTLPCloudflareExporterBase.parseEnv(env, "LOGS"));
  }
  convert(logRecords) {
    const convertedLogs = createExportLogsServiceRequest(logRecords, false);
    const message = ExportLogsServiceRequest.create(convertedLogs);
    return ExportLogsServiceRequest.encode(message).finish();
  }
  getUrl(config) {
    if (typeof config.url === "string") {
      return config.url;
    }
    if (config.endpoints?.logs?.length > 0) {
      return appendRootPathToUrlIfNeeded(config.endpoints.logs);
    }
    if (config.endpoints?.default?.length > 0) {
      return appendResourcePathToUrl(config.endpoints.default, DEFAULT_COLLECTOR_RESOURCE_PATH);
    }
    throw new Error("You must provide a valid URL for this exporter. Make sure either config.url or env.OTEL_EXPORTER_OTLP_ENDPOINT are specified.");
  }
};
export {
  OTLPProtoLogExporter
};
