import {
  opentelemetry
} from "../chunk-JQEWNB4B.js";
import {
  OTLPCloudflareExporterBase
} from "../chunk-WEQB7WXV.js";

// src/exporters/OTLPProtoTraceExporter.ts
import { appendResourcePathToUrl, appendRootPathToUrlIfNeeded } from "@opentelemetry/otlp-exporter-base";
import { createExportTraceServiceRequest } from "@opentelemetry/otlp-transformer";
var {
  proto: {
    collector: {
      trace: {
        v1: { ExportTraceServiceRequest }
      }
    }
  }
} = opentelemetry;
var DEFAULT_COLLECTOR_RESOURCE_PATH = "v1/traces";
var OTLPProtoTraceExporter = class _OTLPProtoTraceExporter extends OTLPCloudflareExporterBase {
  constructor(config) {
    super(config);
    this.contentType = "application/x-protobuf";
  }
  static fromEnv(env) {
    return new _OTLPProtoTraceExporter(OTLPCloudflareExporterBase.parseEnv(env, "TRACES"));
  }
  convert(spans) {
    const convertedSpans = createExportTraceServiceRequest(spans, false);
    const message = ExportTraceServiceRequest.create(convertedSpans);
    return ExportTraceServiceRequest.encode(message).finish();
  }
  getUrl(config) {
    if (typeof config.url === "string") {
      return config.url;
    }
    if (config.endpoints?.traces?.length > 0) {
      return appendRootPathToUrlIfNeeded(config.endpoints.traces);
    }
    if (config.endpoints?.default?.length > 0) {
      return appendResourcePathToUrl(config.endpoints.default, DEFAULT_COLLECTOR_RESOURCE_PATH);
    }
    throw new Error("You must provide a valid URL for this exporter. Make sure either config.url or env.OTEL_EXPORTER_OTLP_ENDPOINT are specified.");
  }
};
export {
  OTLPProtoTraceExporter
};
