import {
  createExportLogsServiceRequest
} from "./chunk-UBB7SZAJ.js";
import {
  OTLPCloudflareExporterBase,
  __privateAdd,
  __privateGet,
  __privateMethod,
  __privateSet
} from "./chunk-WEQB7WXV.js";

// src/index.ts
import * as api from "@opentelemetry/api";
import * as core from "@opentelemetry/core";
import * as tracing from "@opentelemetry/sdk-trace-base";

// src/exporters/OTLPJsonTraceExporter.ts
import { appendResourcePathToUrl, appendRootPathToUrlIfNeeded } from "@opentelemetry/otlp-exporter-base";
import {
  createExportTraceServiceRequest
} from "@opentelemetry/otlp-transformer";
var DEFAULT_COLLECTOR_RESOURCE_PATH = "v1/traces";
var OTLPJsonTraceExporter = class _OTLPJsonTraceExporter extends OTLPCloudflareExporterBase {
  constructor() {
    super(...arguments);
    this.contentType = "application/json";
  }
  static fromEnv(env) {
    return new _OTLPJsonTraceExporter(OTLPCloudflareExporterBase.parseEnv(env, "TRACES"));
  }
  convert(spans) {
    return createExportTraceServiceRequest(spans, true);
  }
  getUrl(config) {
    if (typeof config.url === "string") {
      return config.url;
    }
    if (config.endpoints?.traces?.length > 0) {
      return appendRootPathToUrlIfNeeded(config.endpoints.traces);
    }
    if (config.endpoints?.default?.length > 0) {
      return appendResourcePathToUrl(config.endpoints.default, DEFAULT_COLLECTOR_RESOURCE_PATH);
    }
    throw new Error("You must provide a valid URL for this exporter. Make sure either config.url or env.OTEL_EXPORTER_OTLP_ENDPOINT are specified.");
  }
};

// src/exporters/OTLPJsonLogExporter.ts
import { appendResourcePathToUrl as appendResourcePathToUrl2, appendRootPathToUrlIfNeeded as appendRootPathToUrlIfNeeded2 } from "@opentelemetry/otlp-exporter-base";
var DEFAULT_COLLECTOR_RESOURCE_PATH2 = "v1/logs";
var OTLPJsonLogExporter = class _OTLPJsonLogExporter extends OTLPCloudflareExporterBase {
  constructor() {
    super(...arguments);
    this.contentType = "application/json";
  }
  static fromEnv(env) {
    return new _OTLPJsonLogExporter(OTLPCloudflareExporterBase.parseEnv(env, "LOGS"));
  }
  convert(logRecords) {
    return createExportLogsServiceRequest(logRecords, true);
  }
  getUrl(config) {
    if (typeof config.url === "string") {
      return config.url;
    }
    if (config.endpoints?.logs?.length > 0) {
      return appendRootPathToUrlIfNeeded2(config.endpoints.logs);
    }
    if (config.endpoints?.default?.length > 0) {
      return appendResourcePathToUrl2(config.endpoints.default, DEFAULT_COLLECTOR_RESOURCE_PATH2);
    }
    throw new Error("You must provide a valid URL for this exporter. Make sure either config.url or env.OTEL_EXPORTER_OTLP_ENDPOINT are specified.");
  }
};

// src/sdk.ts
import { Resource } from "@opentelemetry/resources";
import { SpanKind, trace } from "@opentelemetry/api";
import {
  CompositePropagator,
  ExportResultCode as ExportResultCode2,
  hrTime,
  W3CBaggagePropagator,
  W3CTraceContextPropagator,
  _globalThis
} from "@opentelemetry/core";
import { BasicTracerProvider, AlwaysOnSampler } from "@opentelemetry/sdk-trace-base";

// src/EventSpanProcessor.ts
import { ExportResultCode } from "@opentelemetry/core";
var EventSpanProcessor = class {
  constructor(exporter) {
    this.exporter = exporter;
    this.spans = /* @__PURE__ */ new Set();
  }
  forceFlush() {
    return new Promise((resolve, reject) => {
      this.exporter.export(Array.from(this.spans), (result) => {
        if (result.code === ExportResultCode.SUCCESS) {
          this.spans.clear();
          resolve();
        } else {
          reject(result.error);
        }
      });
    });
  }
  onStart(_, __) {
  }
  onEnd(span) {
    this.spans.add(span);
  }
  shutdown() {
    throw new Error("Method not implemented.");
  }
};

// src/SimpleContext.ts
var SimpleContext = class {
  constructor() {
    this._data = /* @__PURE__ */ new Map();
  }
  getValue(key) {
    return this._data.get(key);
  }
  setValue(key, value) {
    this._data.set(key, value);
    return this;
  }
  deleteValue(key) {
    this._data.delete(key);
    return this;
  }
};

// src/sdk.ts
import { SemanticResourceAttributes, SemanticAttributes } from "@opentelemetry/semantic-conventions";

// node_modules/diary/diary/browser/index.mjs
var e = [];
var a = (e2) => new RegExp(e2.replace(/\*/g, ".*") + "$");
var r = (r2) => {
  e = r2.split(/[\s,]+/).map(a);
};
var s = (a2, r2, s2, ...l2) => {
  for (let n2 = e.length; n2--; )
    if (e[n2].test(a2))
      return r2({ name: a2, level: s2, messages: l2 });
};
var l = (e2) => {
  let a2 = "";
  const r2 = console["fatal" === e2.level ? "error" : e2.level];
  if (e2.name && (a2 += `[${e2.name}] `), "object" == typeof e2.messages[0])
    r2(a2, ...e2.messages);
  else {
    r2(a2 + e2.messages.shift(), ...e2.messages);
  }
};
var n = (e2, a2) => ({ fatal: s.bind(0, e2, a2 = a2 || l, "fatal"), error: s.bind(0, e2, a2, "error"), warn: s.bind(0, e2, a2, "warn"), debug: s.bind(0, e2, a2, "debug"), info: s.bind(0, e2, a2, "info"), log: s.bind(0, e2, a2, "log") });
var o = n("");
var t = o.fatal;
var g = o.error;
var i = o.warn;
var f = o.debug;
var b = o.info;
var d = o.log;

// src/HeadersTextExtractor.ts
var HeadersTextMapper = class {
  keys(carrier) {
    return Array.from(carrier.keys());
  }
  get(carrier, key) {
    if (key.toLowerCase() === "set-cookie") {
      return carrier.getAll(key);
    }
    return carrier.get(key);
  }
  set(carrier, key, value) {
    carrier.set(key, value);
  }
};

// src/utils.ts
function cloneRequest(request) {
  const url = new URL(request.url);
  return new Request(url.toString(), new Request(request, {}));
}

// src/sdk.ts
var headersTextMapper = new HeadersTextMapper();
var _flushed, _logs, _env, _ingestEvent, ingestEvent_fn, _parseAttributes, parseAttributes_fn, _isValidAttributeKey, isValidAttributeKey_fn, _isPrintableString, isPrintableString_fn, _isValidAndNotEmptyKey, isValidAndNotEmptyKey_fn;
var _WorkersSDK = class _WorkersSDK {
  constructor(eventOrRequest, ctx, envOrConfig, configOrUnk) {
    this.eventOrRequest = eventOrRequest;
    this.ctx = ctx;
    __privateAdd(this, _ingestEvent);
    this.allowedHeaders = ["user-agent", "cf-ray"];
    this.allowedSearch = /.*/;
    __privateAdd(this, _flushed, false);
    __privateAdd(this, _logs, []);
    __privateAdd(this, _env, void 0);
    this.res = this.sendResponse.bind(this);
    let config;
    let env = {};
    if (configOrUnk == null) {
      config = envOrConfig;
    } else {
      config = configOrUnk;
      env = envOrConfig;
    }
    __privateSet(this, _env, env);
    if (config.service == null || config.service?.length == 0) {
      throw new Error("You must provide a service name via `service`.");
    }
    const resource = config.resource ?? new Resource({
      [SemanticResourceAttributes.TELEMETRY_SDK_NAME]: "opentelemetry-sdk-workers",
      [SemanticResourceAttributes.CLOUD_PROVIDER]: "cloudflare",
      [SemanticResourceAttributes.CLOUD_PLATFORM]: "workers",
      [SemanticResourceAttributes.SERVICE_NAME]: config.service,
      [SemanticResourceAttributes.FAAS_NAME]: config.service,
      [SemanticResourceAttributes.PROCESS_RUNTIME_NAME]: "Cloudflare-Workers"
    });
    if ("traceExporter" in config) {
      this.traceExporter = config.traceExporter;
    } else {
      const { endpoint, ...exporterConfig } = config;
      this.traceExporter = new OTLPJsonTraceExporter({
        endpoints: { default: endpoint },
        ...exporterConfig
      });
    }
    const sampler = config.sampler ?? new AlwaysOnSampler();
    this.traceProvider = new BasicTracerProvider({
      sampler,
      resource,
      forceFlushTimeoutMillis: 5e3
    });
    const spanProcessor = new EventSpanProcessor(this.traceExporter);
    this.traceProvider.addSpanProcessor(spanProcessor);
    this.propagator = config.propagator ?? new CompositePropagator({
      propagators: [new W3CTraceContextPropagator(), new W3CBaggagePropagator()]
    });
    this.requestTracer = this.traceProvider.getTracer("opentelemetry-sdk-workers", "0.1.0");
    const { span, spanContext } = this.initSpan();
    this.span = span;
    this.spanContext = spanContext;
    this.logExporter = config.logExporter;
    this.logExportEnabled = config.logExporter != null;
    this.consoleLogEnabled = config.consoleLogEnabled ?? false;
    r("*");
    this.logger = n(config.service, (event) => {
      const { name, level, messages } = event;
      const consoleLevel = level === "fatal" ? "error" : level;
      if (this.consoleLogEnabled) {
        const [message, extra] = messages;
        console[consoleLevel](message, extra);
      }
      if (this.logExporter) {
        __privateMethod(this, _ingestEvent, ingestEvent_fn).call(this, event);
      }
    });
  }
  get env() {
    return new Proxy(__privateGet(this, _env), {
      get: (target, prop, reciever) => {
        const binding = Reflect.get(target, prop, reciever);
        return {
          fetch: (request, init) => {
            return this._fetch(binding, request, init);
          }
        };
      }
    });
  }
  static fromEnv(eventOrRequest, env, ctx, config = {}) {
    const rawAttributes = env["OTEL_RESOURCE_ATTRIBUTES"];
    const attributes = __privateMethod(this, _parseAttributes, parseAttributes_fn).call(this, rawAttributes);
    const serviceName = env["OTEL_SERVICE_NAME"];
    if (serviceName === null) {
      throw new Error("You must provide a service name via env.OTEL_SERVICE_NAME.");
    }
    if (serviceName) {
      attributes[SemanticResourceAttributes.SERVICE_NAME] = serviceName;
    }
    const resource = new Resource(attributes).merge(new Resource({
      [SemanticResourceAttributes.TELEMETRY_SDK_NAME]: "opentelemetry-sdk-workers",
      [SemanticResourceAttributes.CLOUD_PROVIDER]: "cloudflare",
      [SemanticResourceAttributes.CLOUD_PLATFORM]: "workers",
      [SemanticResourceAttributes.FAAS_NAME]: attributes[SemanticResourceAttributes.SERVICE_NAME],
      [SemanticResourceAttributes.PROCESS_RUNTIME_NAME]: "Cloudflare-Workers"
    }));
    const rawLoggingValue = env["OTEL_EXPORTER_LOGS_ENABLED"];
    const rawConsoleLogValue = env["OTEL_EXPORTER_LOGS_CONSOLE_ENABLED"];
    const loggingEnabled = rawLoggingValue === "1" || rawLoggingValue === "true";
    const consoleEnabled = rawConsoleLogValue === "1" || rawConsoleLogValue === "true";
    return new _WorkersSDK(eventOrRequest, ctx, env, {
      service: attributes[SemanticResourceAttributes.SERVICE_NAME],
      resource,
      traceExporter: OTLPJsonTraceExporter.fromEnv(env),
      logExporter: loggingEnabled ? OTLPJsonLogExporter.fromEnv(env) : void 0,
      consoleLogEnabled: consoleEnabled,
      ...config
    });
  }
  async fetch(request, requestInitr) {
    return this._fetch(_globalThis, request, requestInitr);
  }
  sendResponse(response) {
    this.span.setAttributes({
      [SemanticAttributes.HTTP_STATUS_CODE]: response.status
    });
    for (const headerKey of response.headers.keys()) {
      if (headerKey === "set-cookie") {
        continue;
      }
      if (!this.allowedHeaders.some(
        (allowed) => typeof allowed === "string" ? headerKey === allowed : allowed.test(headerKey)
      )) {
        continue;
      }
      this.span.setAttribute(`http.response.header.${headerKey.toLowerCase()}`, [
        response.headers.get(headerKey)
      ]);
    }
    let endTime = Date.now();
    if (this.startTime === endTime) {
      endTime += 0.01;
    }
    this.span.end(endTime);
    this.ctx.waitUntil(this.end());
    return response;
  }
  captureException(ex) {
    this.span.recordException(ex);
    let endTime = Date.now();
    if (this.startTime === endTime) {
      endTime += 0.01;
    }
    this.span.end(endTime);
    this.ctx.waitUntil(this.end());
  }
  async _fetch(fetchTarget, request, requestInitr) {
    let downstreamRequest;
    if (request instanceof Request) {
      downstreamRequest = cloneRequest(request);
    } else {
      downstreamRequest = new Request(request, requestInitr);
    }
    const childSpan = this.createSpan(downstreamRequest);
    this.propagator.inject(this.spanContext, downstreamRequest.headers, headersTextMapper);
    if (__privateGet(this, _flushed)) {
      console.warn(
        "Fetch request sent after worker spans were flushed. Avoid using instance.fetch after calling sendResponse or captureException."
      );
    }
    try {
      const response = await fetchTarget.fetch(downstreamRequest);
      this.endSpan(downstreamRequest, childSpan, response);
      return response;
    } catch (reason) {
      this.endSpan(downstreamRequest, childSpan, reason);
      return reason;
    }
  }
  createSpan(request) {
    const method = (request.method ?? "GET").toUpperCase();
    const spanName = `HTTP ${method}`;
    const url = new URL(request.url);
    const childSpan = this.requestTracer.startSpan(spanName, {
      kind: SpanKind.CLIENT,
      attributes: {
        [SemanticAttributes.HTTP_METHOD]: method,
        [SemanticAttributes.HTTP_URL]: request.url,
        [SemanticAttributes.HTTP_TARGET]: `${url.pathname}${url.search}`,
        [SemanticAttributes.HTTP_HOST]: url.host,
        [SemanticAttributes.HTTP_SCHEME]: url.protocol.replace(":", "")
      }
    }, this.spanContext);
    trace.setSpan(this.spanContext, childSpan);
    return childSpan;
  }
  endSpan(request, span, responseOrError) {
    const url = new URL("url" in responseOrError ? responseOrError.url : request.url);
    if (responseOrError instanceof Response) {
      span.setAttribute(SemanticAttributes.HTTP_STATUS_CODE, responseOrError.status);
    } else {
      span.setAttribute(SemanticAttributes.HTTP_STATUS_CODE, responseOrError["status"] ?? 0);
      span.recordException(responseOrError, /* @__PURE__ */ new Date());
    }
    span.end(/* @__PURE__ */ new Date());
  }
  async end() {
    try {
      const exportPromises = [
        this.traceProvider.forceFlush()
      ];
      if (this.logExporter) {
        exportPromises.push(new Promise((resolve, reject) => {
          this.logExporter.export(__privateGet(this, _logs), (result) => {
            if (result.code === ExportResultCode2.SUCCESS) {
              resolve();
            } else {
              reject(result.error);
            }
          });
        }));
      }
      await Promise.all(exportPromises);
    } catch (error) {
      console.error("Failed to exporter open telemetry data:", error);
      console.error("Make sure that your endpoint and/or exporters are correctly configured.");
    }
  }
  initSpan() {
    const context = new SimpleContext();
    let name;
    if ("type" in this.eventOrRequest) {
      const scheduledEvent = this.eventOrRequest;
      name = `scheduled ${scheduledEvent.cron ?? scheduledEvent.scheduledTime}`;
    } else {
      if (!this.eventOrRequest) {
        throw new Error("You must provide the request to start for fetch events!");
      }
      const url = new URL(this.eventOrRequest.url);
      name = `fetch ${this.eventOrRequest.method} ${url.pathname}`;
      this.propagator.extract(context, this.eventOrRequest.headers, headersTextMapper);
    }
    const span = this.requestTracer.startSpan(
      name,
      {
        // TODO: What is the right SpanKind for cron jobs?
        kind: "type" in this.eventOrRequest ? SpanKind.SERVER : SpanKind.INTERNAL,
        startTime: Date.now()
      },
      context
    );
    trace.setSpan(context, span);
    if ("type" in this.eventOrRequest) {
      const scheduledEvent = this.eventOrRequest;
      span.setAttribute(SemanticAttributes.FAAS_TRIGGER, "timer");
      span.setAttribute(SemanticAttributes.FAAS_TIME, scheduledEvent.scheduledTime);
      if (scheduledEvent.cron) {
        span.setAttribute(SemanticAttributes.FAAS_CRON, scheduledEvent.cron);
      }
    } else {
      const request = this.eventOrRequest;
      const url = new URL(request.url);
      const searchParams = new URLSearchParams();
      for (const [key, value] of url.searchParams) {
        if (Array.isArray(this.allowedSearch)) {
          if (this.allowedSearch.some(
            (allowed) => typeof allowed === "string" ? allowed === key : allowed.test(key)
          )) {
            searchParams.append(key, value);
          }
        } else if (this.allowedSearch.test(key)) {
          searchParams.append(key, value);
        }
      }
      const search = searchParams.toString();
      const target = `${url.pathname}${search === "" ? "" : `?${search}`}`;
      span.setAttributes({
        [SemanticAttributes.HTTP_METHOD]: request.method,
        [SemanticAttributes.HTTP_URL]: request.url,
        [SemanticAttributes.HTTP_TARGET]: target,
        [SemanticAttributes.HTTP_HOST]: url.host,
        [SemanticAttributes.NET_HOST_NAME]: url.hostname,
        [SemanticAttributes.NET_HOST_PORT]: url.port,
        [SemanticAttributes.HTTP_SCHEME]: url.protocol.substring(0, url.protocol.length - 1),
        [SemanticAttributes.HTTP_USER_AGENT]: request.headers.get("user-agent"),
        [SemanticAttributes.NET_PEER_IP]: request.headers.get("cf-connecting-ip"),
        [SemanticAttributes.HTTP_CLIENT_IP]: request.headers.get("cf-connecting-ip")
      });
      for (const headerKey of request.headers.keys()) {
        if (headerKey === "cookie") {
          continue;
        }
        if (!this.allowedHeaders.some(
          (allowed) => typeof allowed === "string" ? headerKey === allowed : allowed.test(headerKey)
        )) {
          continue;
        }
        span.setAttribute(`http.request.header.${headerKey.toLowerCase()}`, [request.headers.get(headerKey)]);
      }
    }
    return { span, spanContext: context };
  }
};
_flushed = new WeakMap();
_logs = new WeakMap();
_env = new WeakMap();
_ingestEvent = new WeakSet();
ingestEvent_fn = function(event) {
  const { spanId, traceId, traceFlags } = this.span.spanContext();
  const { level: defaultLevel, name, messages } = event;
  const level = defaultLevel === "log" ? "info" : defaultLevel;
  let severityNumber;
  switch (level) {
    case "debug":
      severityNumber = 5;
      break;
    case "info":
      severityNumber = 9;
      break;
    case "warn":
      severityNumber = 13;
      break;
    case "error":
      severityNumber = 17;
      break;
    case "fatal":
      severityNumber = 21;
      break;
  }
  const [message, extra] = messages;
  __privateGet(this, _logs).push({
    timestamp: hrTime(Date.now()),
    observedTimestamp: hrTime(Date.now()),
    spanId,
    traceId,
    traceFlags,
    severityText: level.toUpperCase(),
    severityNumber,
    body: `${message}`,
    instrumentationLibrary: {
      name: "opentelemetry-sdk-workers"
    },
    resource: this.traceProvider.resource,
    attributes: {
      "log.extra": extra
    }
  });
};
_parseAttributes = new WeakSet();
parseAttributes_fn = function(rawEnvAttributes) {
  if (!rawEnvAttributes)
    return {};
  const attributes = {};
  const rawAttributes = rawEnvAttributes.split(",", -1);
  for (const rawAttribute of rawAttributes) {
    const keyValuePair = rawAttribute.split("=", -1);
    if (keyValuePair.length !== 2) {
      continue;
    }
    let [key, value] = keyValuePair;
    key = key.trim();
    value = value.trim().split('^"|"$').join("");
    if (!__privateMethod(this, _isValidAndNotEmptyKey, isValidAndNotEmptyKey_fn).call(this, key)) {
      throw new Error(`Attribute key should be a ASCII string with a length greater than 0 and not exceed 255 characters.`);
    }
    if (!__privateMethod(this, _isValidAttributeKey, isValidAttributeKey_fn).call(this, value)) {
      throw new Error(`Attribute value should be a ASCII string with a length not exceed 255 characters`);
    }
    attributes[key] = value;
  }
  return attributes;
};
_isValidAttributeKey = new WeakSet();
isValidAttributeKey_fn = function(name) {
  return name.length <= 255 && __privateMethod(this, _isPrintableString, isPrintableString_fn).call(this, name);
};
_isPrintableString = new WeakSet();
isPrintableString_fn = function(str) {
  for (let i2 = 0; i2 < str.length; i2++) {
    const ch = str.charAt(i2);
    if (ch <= " " || ch >= "~") {
      return false;
    }
  }
  return true;
};
_isValidAndNotEmptyKey = new WeakSet();
isValidAndNotEmptyKey_fn = function(str) {
  return str.length > 0 && __privateMethod(this, _isValidAttributeKey, isValidAttributeKey_fn).call(this, str);
};
/**
 * Implementation of OTEL_RESOURCE_ATTRIBUTES adapted from @opentelemetry/api's EnvDetector.
 * @param rawEnvAttributes OTEL_RESOURCE_ATTRIBUTES Environment Variable
 * @returns parses attributes
 */
__privateAdd(_WorkersSDK, _parseAttributes);
/**
 * Determines whether the given String is a valid printable ASCII string with
 * a length not exceed _MAX_LENGTH characters.
 *
 * @param str The String to be validated.
 * @returns Whether the String is valid.
 */
__privateAdd(_WorkersSDK, _isValidAttributeKey);
__privateAdd(_WorkersSDK, _isPrintableString);
/**
 * Determines whether the given String is a valid printable ASCII string with
 * a length greater than 0 and not exceed _MAX_LENGTH characters.
 *
 * @param str The String to be validated.
 * @returns Whether the String is valid and not empty.
 */
__privateAdd(_WorkersSDK, _isValidAndNotEmptyKey);
var WorkersSDK = _WorkersSDK;
export {
  OTLPJsonLogExporter,
  OTLPJsonTraceExporter,
  WorkersSDK,
  api,
  core,
  tracing
};
