// src/performance.ts
var unsupportedMethods = [
  "mark",
  "clearMarks",
  "measure",
  "clearMeasures",
  "getEntries",
  "getEntriesByType",
  "getEntriesByName"
];
var UnsupportedMethodError = class extends Error {
  constructor(method) {
    super(`The method '${method}' is not supported by this polyfill.`);
    this.method = method;
    this.name = "UnsupportedMethodError";
  }
};
var performanceShim = new Proxy(
  {
    now: () => Date.now(),
    // TODO: How should this behave in a worker?
    timeOrigin: Date.now()
  },
  {
    get(target, prop, receiver) {
      if (unsupportedMethods.includes(prop)) {
        throw new UnsupportedMethodError(prop.toString());
      }
      return Reflect.get(target, prop, receiver);
    }
  }
);
globalThis["performance"] = performanceShim;
